@@ -130,7 +130,6 @@ $set 10 #Menu
 7 Placement
 8 Reload Config
 9 Restart
-10 xterm
 
 $set 11 #Remember
 
@@ -151,10 +150,7 @@ $set 12 #Screen
 
 1 BScreen::BScreen: an error occured while querying the X server.\n	another window manager already running on display
 2 W: %4d x H: %4d
-3 W: 0000 x H: 0000
-4 BScreen::BScreen: managing screen %d using visual 0x%lx, depth %d\n
-5 X: %4d x Y: %4d
-6 0: 0000 x 0: 0000
+3 BScreen::BScreen: managing screen %d using visual 0x%lx, depth %d\n
 
 $set 13 #Slit
 
@@ -215,10 +211,9 @@ $set 17 #Workspace
 
 $set 18 #fbsetroot
 
-1 %s: error: must specify one of: -solid, -mod, -gradient\n
+1 Error: must specify one of: -solid, -mod, -gradient\n
 2 Couldn't create pixmap atoms, giving up!
-3 %s 2.0: (c) 1997-2000 Brad Hughes\n\n\
--display <string>        display connection\n\
+3 -display <string>        display connection\n\
 -mod <x> <y>             modula pattern\n\
 -foreground, -fg <color> modula foreground color\n\
 -background, -bg <color> modula background color\n\n\
@@ -230,7 +225,7 @@ $set 18 #fbsetroot
 
 $set 19 #main
 
-1 error: '-display' requires an argument\n
+1 error: '-display' requires an argument
 2 Bad Alloc
 3 Bad cast
 4 Out of range
@@ -240,15 +235,18 @@ $set 19 #main
 8 error: '-log' needs an argument
 9 Log File
 10 Logging to
-11 error: '-rc' requires an argument\n
-12 Fluxbox %s: (c) %s Henrik Kinnunen\n\n\
+11 error: '-rc' requires an argument
+12 error: '-screen' requires an argument
+13 Fluxbox %s: (c) %s Henrik Kinnunen\n\
+Website: http://www.fluxbox.org/\n\n\
 -display <string>\t\tuse display connection.\n\
+-screen <all|int,int,int>\trun on specified screens only.\n\
 -rc <string>\t\t\tuse alternate resource file.\n\
 -version\t\t\tdisplay version and exit.\n\
 -info\t\t\t\tdisplay some useful information.\n\
 -log <filename>\t\t\tlog output to file.\n\
 -help\t\t\t\tdisplay this help text and exit.\n\n
-13 warning: couldn't set environment variable 'DISPLAY'
+14 warning: couldn't set environment variable 'DISPLAY'
 
 $set 20
 
