@@ -1,5 +1,5 @@
 // CurrentWindowCmd.cc for Fluxbox - an X11 Window manager
-// Copyright (c) 2003 - 2005 Henrik Kinnunen (fluxgen at fluxbox dot org)
+// Copyright (c) 2003 - 2006 Henrik Kinnunen (fluxgen at fluxbox dot org)
 //                and Simon Bowden (rathnor at users.sourceforge.net)
 //
 // Permission is hereby granted, free of charge, to any person obtaining a
@@ -20,7 +20,7 @@
 // FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 // DEALINGS IN THE SOFTWARE.
 
-// $Id: CurrentWindowCmd.cc 4076 2005-07-05 21:57:33Z mathias $
+// $Id: CurrentWindowCmd.cc 4206 2006-02-18 20:19:22Z fluxgen $
 
 #include "CurrentWindowCmd.hh"
 
@@ -29,10 +29,12 @@
 #include "Screen.hh"
 #include "WinClient.hh"
 
+#include "FocusControl.hh"
+
 CurrentWindowCmd::CurrentWindowCmd(Action act):m_action(act) { }
 
 void CurrentWindowCmd::execute() {
-    WinClient *client = Fluxbox::instance()->getFocusedWindow();
+    WinClient *client = FocusControl::focusedWindow();
     if (client && client->fbwindow())
         (client->fbwindow()->*m_action)();
 }
@@ -95,19 +97,19 @@ void GoToTabCmd::real_execute() {
 }
 
 void WindowHelperCmd::execute() {
-    WinClient *client = Fluxbox::instance()->getFocusedWindow();
+    WinClient *client = FocusControl::focusedWindow();
     if (client && client->fbwindow()) // guarantee that fbwindow() exists too
         real_execute();
 }
 
 WinClient &WindowHelperCmd::winclient() {
     // will exist from execute above
-    return *Fluxbox::instance()->getFocusedWindow();
+    return *FocusControl::focusedWindow();
 }
 
 FluxboxWindow &WindowHelperCmd::fbwindow() {
     // will exist from execute above
-    return *Fluxbox::instance()->getFocusedWindow()->fbwindow();
+    return *FocusControl::focusedWindow()->fbwindow();
 }
 
 MoveCmd::MoveCmd(const int step_size_x, const int step_size_y) :
