@@ -1,5 +1,5 @@
 // FbCommandFactory.cc for Fluxbox Window manager
-// Copyright (c) 2003 - 2005 Henrik Kinnunen (fluxgen at fluxbox dot org)
+// Copyright (c) 2003 - 2006 Henrik Kinnunen (fluxgen at fluxbox dot org)
 //                and Simon Bowden (rathnor at users.sourceforge.net)
 //
 // Permission is hereby granted, free of charge, to any person obtaining a
@@ -20,7 +20,7 @@
 // FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 // DEALINGS IN THE SOFTWARE.
 
-// $Id: FbCommandFactory.cc 4051 2005-06-15 15:17:48Z mathias $
+// $Id: FbCommandFactory.cc 4233 2006-03-09 19:38:18Z mathias $
 
 #include "FbCommandFactory.hh"
 
@@ -350,10 +350,10 @@ FbTk::Command *FbCommandFactory::stringToCommand(const std::string &command,
     // 
     // Workspace commands
     //
-    else if (command == "nextworkspace" && arguments.empty())
-        return new NextWorkspaceCmd();
-    else if (command == "prevworkspace" && arguments.empty())
-        return new PrevWorkspaceCmd();
+    else if (command == "nextworkspace")
+        return new NextWorkspaceCmd(atoi(arguments.c_str()));
+    else if (command == "prevworkspace")
+        return new PrevWorkspaceCmd(atoi(arguments.c_str()));
     else if (command == "rightworkspace")
         return new RightWorkspaceCmd(atoi(arguments.c_str()));
     else if (command == "leftworkspace")
@@ -374,17 +374,17 @@ FbTk::Command *FbCommandFactory::stringToCommand(const std::string &command,
     else if (command == "prevwindow")
         return new PrevWindowCmd(atoi(arguments.c_str()));
     else if (command == "focusup")
-        return new DirFocusCmd(BScreen::FOCUSUP);
+        return new DirFocusCmd(FocusControl::FOCUSUP);
     else if (command == "focusdown")
-        return new DirFocusCmd(BScreen::FOCUSDOWN);
+        return new DirFocusCmd(FocusControl::FOCUSDOWN);
     else if (command == "focusleft")
-        return new DirFocusCmd(BScreen::FOCUSLEFT);
+        return new DirFocusCmd(FocusControl::FOCUSLEFT);
     else if (command == "focusright")
-        return new DirFocusCmd(BScreen::FOCUSRIGHT);
+        return new DirFocusCmd(FocusControl::FOCUSRIGHT);
     else if (command == "nextgroup")
-        return new NextWindowCmd(atoi(arguments.c_str()) ^ BScreen::CYCLEGROUPS);
+        return new NextWindowCmd(atoi(arguments.c_str()) ^ FocusControl::CYCLEGROUPS);
     else if (command == "prevgroup")
-        return new PrevWindowCmd(atoi(arguments.c_str()) ^ BScreen::CYCLEGROUPS);
+        return new PrevWindowCmd(atoi(arguments.c_str()) ^ FocusControl::CYCLEGROUPS);
     else if (command == "arrangewindows")
         return new ArrangeWindowsCmd();
     else if (command == "showdesktop")
