@@ -1,5 +1,5 @@
 // FbWinFrame.cc for Fluxbox Window Manager
-// Copyright (c) 2003 - 2005 Henrik Kinnunen (fluxgen at fluxbox dot org)
+// Copyright (c) 2003 - 2006 Henrik Kinnunen (fluxgen at fluxbox dot org)
 //
 // Permission is hereby granted, free of charge, to any person obtaining a
 // copy of this software and associated documentation files (the "Software"),
@@ -19,7 +19,7 @@
 // FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 // DEALINGS IN THE SOFTWARE.
 
-// $Id: FbWinFrame.cc 4085 2005-07-25 23:17:41Z mathias $
+// $Id: FbWinFrame.cc 4215 2006-02-19 11:44:57Z fluxgen $
 
 #include "FbWinFrame.hh"
 
@@ -32,7 +32,6 @@
 #include "FbTk/Transparent.hh"
 #include "CompareWindow.hh"
 #include "FbWinFrameTheme.hh"
-#include "fluxbox.hh"
 
 #include "Container.hh"
 
@@ -332,7 +331,8 @@ void FbWinFrame::removeAllButtons() {
     }
 }
 
-FbWinFrame::ButtonId FbWinFrame::createTab(const std::string &title, FbTk::Command *command) {
+FbWinFrame::ButtonId FbWinFrame::createTab(const std::string &title, FbTk::Command *command,
+                                           int tabs_padding) {
     FbTk::TextButton *button = new FbTk::TextButton(m_tab_container,
                                                     theme().font(),
                                                     title);
@@ -346,7 +346,7 @@ FbWinFrame::ButtonId FbWinFrame::createTab(const std::string &title, FbTk::Comma
     FbTk::RefCount<FbTk::Command> refcmd(command);
     button->setOnClick(refcmd);
 
-    button->setTextPadding(Fluxbox::instance()->getTabsPadding());
+    button->setTextPadding(tabs_padding);
     button->setJustify(theme().justify());
 
     m_tab_container.insertItem(button);
@@ -382,19 +382,29 @@ void FbWinFrame::moveLabelButtonTo(FbTk::TextButton &btn, int x, int y) {
 
 
 void FbWinFrame::moveLabelButtonLeftOf(FbTk::TextButton &btn, const FbTk::TextButton &dest) {
-    int pos = m_tab_container.find(&dest);
-    if (pos < 0)
+    int dest_pos = m_tab_container.find(&dest);
+    int cur_pos = m_tab_container.find(&btn);
+    if (dest_pos < 0 || cur_pos < 0)
         return;
+    int movement=dest_pos - cur_pos;
+    if(movement>0)
+        movement-=1;
+//    else
+  //      movement-=1;
 
-    m_tab_container.moveItem(&btn, pos-1);
+    m_tab_container.moveItem(&btn, movement);
 }
 
 void FbWinFrame::moveLabelButtonRightOf(FbTk::TextButton &btn, const FbTk::TextButton &dest) {
-    int pos = m_tab_container.find(&dest);
-    if (pos < 0)
+    int dest_pos = m_tab_container.find(&dest);
+    int cur_pos = m_tab_container.find(&btn);
+    if (dest_pos < 0 || cur_pos < 0 )
         return;
+    int movement=dest_pos - cur_pos;
+    if(movement<0)
+        movement+=1;
 
-    m_tab_container.moveItem(&btn, pos+1);
+    m_tab_container.moveItem(&btn, movement);
 }
 
 void FbWinFrame::setLabelButtonFocus(FbTk::TextButton &btn) {
