@@ -1,5 +1,5 @@
 // SendToMenu.cc for Fluxbox
-// Copyright (c) 2003 - 2005 Henrik Kinnunen (fluxgen at fluxbox dot org)
+// Copyright (c) 2003 - 2006 Henrik Kinnunen (fluxgen at fluxbox dot org)
 //                and Simon Bowden    (rathnor at users.sourceforge.net)
 // 
 // Permission is hereby granted, free of charge, to any person obtaining a
@@ -20,15 +20,16 @@
 // FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 // DEALINGS IN THE SOFTWARE.
 
-// $Id: SendToMenu.cc 4062 2005-06-23 03:07:25Z fluxgen $
+// $Id: SendToMenu.cc 4221 2006-02-20 21:04:35Z fluxgen $
 
 #include "SendToMenu.hh"
 
 #include "Window.hh"
 #include "Screen.hh"
-#include "fluxbox.hh"
 #include "Workspace.hh"
 #include "WindowCmd.hh"
+#include "fluxbox.hh"
+#include "Layer.hh"
 
 #include "FbTk/MultiButtonMenuItem.hh"
 #include "FbTk/Command.hh"
@@ -50,7 +51,7 @@ private:
 SendToMenu::SendToMenu(BScreen &screen):
     FbMenu(screen.menuTheme(),
            screen.imageControl(), 
-           *screen.layerManager().getLayer(Fluxbox::instance()->getMenuLayer())) {
+           *screen.layerManager().getLayer(Layer::MENU)) {
     // listen to:
     // workspace count signal
     // workspace names signal
