@@ -1,5 +1,5 @@
 // Slit.cc for fluxbox
-// Copyright (c) 2002 - 2005 Henrik Kinnunen (fluxgen at fluxbox dot org)
+// Copyright (c) 2002 - 2006 Henrik Kinnunen (fluxgen at fluxbox dot org)
 //
 // Slit.cc for Blackbox - an X11 Window manager
 // Copyright (c) 1997 - 2000 Brad Hughes (bhughes at tcac.net)
@@ -22,7 +22,7 @@
 // FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 // DEALINGS IN THE SOFTWARE.
 
-// $Id: Slit.cc 4062 2005-06-23 03:07:25Z fluxgen $
+// $Id: Slit.cc 4227 2006-03-02 07:49:13Z mathias $
 
 #include "Slit.hh"
 
@@ -43,19 +43,24 @@
 #include "SimpleCommand.hh"
 #include "MacroCommand.hh"
 #include "FbCommands.hh"
+#include "Layer.hh"
 #include "LayerMenu.hh"
-#include "fluxbox.hh"
 #include "XLayer.hh"
 #include "RootTheme.hh"
 #include "FbTk/Theme.hh"
 #include "FbMenu.hh"
 #include "Transparent.hh"
 #include "IntResMenuItem.hh"
+
+#ifdef XINERAMA
 #include "Xinerama.hh"
+#endif // XINERAMA
+
 #include "SlitTheme.hh"
 #include "SlitClient.hh"
 #include "Xutil.hh"
 #include "FbAtoms.hh"
+#include "FbTk/App.hh"
 #include "FbTk/MenuSeparator.hh"
 #include "FbTk/StringUtil.hh"
 #include "FbTk/I18n.hh"
@@ -80,6 +85,8 @@
 #include <algorithm>
 using namespace std;
 
+namespace FbTk {
+
 template<>
 void FbTk::Resource<Slit::Placement>::setFromString(const char *strval) {
     if (strcasecmp(strval, "TopLeft")==0)
@@ -115,7 +122,7 @@ void FbTk::Resource<Slit::Direction>::setFromString(const char *strval) {
 }
 
 template<>
-string FbTk::Resource<Slit::Placement>::getString() {
+string FbTk::Resource<Slit::Placement>::getString() const {
     switch (m_value) {
     case Slit::TOPLEFT:
         return string("TopLeft");
@@ -147,7 +154,7 @@ string FbTk::Resource<Slit::Placement>::getString() {
 }
 
 template<>
-string FbTk::Resource<Slit::Direction>::getString() {
+string FbTk::Resource<Slit::Direction>::getString() const {
     switch (m_value) {
     case Slit::VERTICAL:
         return string("Vertical");
@@ -159,7 +166,7 @@ string FbTk::Resource<Slit::Direction>::getString() {
     // default string
     return string("Vertical");
 }
-
+} // end namespace FbTk
 namespace { 
 
 class SlitClientMenuItem: public FbTk::MenuItem{
@@ -252,13 +259,13 @@ Slit::Slit(BScreen &scr, FbTk::XLayer &layer, const char *filename)
       m_screen(scr),
       m_slitmenu(scr.menuTheme(), 
                  scr.imageControl(),
-                 *scr.layerManager().getLayer(Fluxbox::instance()->getMenuLayer())),
+                 *scr.layerManager().getLayer(Layer::MENU)),
       m_placement_menu(scr.menuTheme(),
                        scr.imageControl(),
-                       *scr.layerManager().getLayer(Fluxbox::instance()->getMenuLayer())),
+                       *scr.layerManager().getLayer(Layer::MENU)),
       m_clientlist_menu(scr.menuTheme(),
                         scr.imageControl(),
-                        *scr.layerManager().getLayer(Fluxbox::instance()->getMenuLayer())),
+                        *scr.layerManager().getLayer(Layer::MENU)),
       frame(scr.rootWindow()),
        //For KDE dock applets
       m_kwm1_dockwindow(XInternAtom(FbTk::App::instance()->display(), 
@@ -284,7 +291,7 @@ Slit::Slit(BScreen &scr, FbTk::XLayer &layer, const char *filename)
                  scr.name() + ".slit.alpha", scr.altName() + ".Slit.Alpha"),
       m_rc_on_head(scr.resourceManager(), 0,
                    scr.name() + ".slit.onhead", scr.altName() + ".Slit.onHead"),
-      m_rc_layernum(scr.resourceManager(), Fluxbox::Layer(Fluxbox::instance()->getDockLayer()), 
+      m_rc_layernum(scr.resourceManager(), Layer(Layer::DOCK), 
                     scr.name() + ".slit.layer", scr.altName() + ".Slit.Layer") {
 
     _FB_USES_NLS;
@@ -317,7 +324,7 @@ Slit::Slit(BScreen &scr, FbTk::XLayer &layer, const char *filename)
     m_layermenu.reset(new LayerMenu(scr.menuTheme(),
                                     scr.imageControl(),
                                     *scr.layerManager().
-                                    getLayer(Fluxbox::instance()->getMenuLayer()), 
+                                    getLayer(Layer::MENU), 
                                     this,
                                     true));
     m_layermenu->setLabel(_FBTEXT(Slit, Layer, "Slit Layer", "Title of Slit Layer Menu"));
@@ -1240,13 +1247,13 @@ void Slit::setupMenu() {
                               screen().menuTheme(),
                               screen(),
                               screen().imageControl(),
-                              *screen().layerManager().getLayer(Fluxbox::instance()->getMenuLayer()),
+                              *screen().layerManager().getLayer(::Layer::MENU),
                               *this,
                               _FBTEXT(Slit, OnHead, "Slit on Head", "Title of Slits On Head menu")
                               ));
     }
-                    
 #endif //XINERAMA
+
     m_slitmenu.insert(new BoolMenuItem(_FBTEXT(Common, AutoHide, "Auto hide", "This thing automatically hides when not close by"),
                                        *m_rc_auto_hide,
                                        save_and_reconfigure_slit));
