@@ -1,5 +1,5 @@
 // fluxbox.cc for Fluxbox Window Manager
-// Copyright (c) 2001 - 2005 Henrik Kinnunen (fluxgen at fluxbox dot org)
+// Copyright (c) 2001 - 2006 Henrik Kinnunen (fluxgen at fluxbox dot org)
 //
 // blackbox.cc for blackbox - an X11 Window manager
 // Copyright (c) 1997 - 2000 Brad Hughes (bhughes at tcac.net)
@@ -22,7 +22,7 @@
 // FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 // DEALINGS IN THE SOFTWARE.
 
-// $Id: fluxbox.cc 4084 2005-07-20 18:29:01Z mathias $
+// $Id: fluxbox.cc 4246 2006-03-18 22:01:22Z fluxgen $
 
 #include "fluxbox.hh"
 
@@ -34,6 +34,9 @@
 #include "WinClient.hh"
 #include "Keys.hh"
 #include "FbAtoms.hh"
+#include "FocusControl.hh"
+#include "Layer.hh"
+
 #include "defaults.hh"
 
 #include "FbTk/I18n.hh"
@@ -183,11 +186,6 @@ int handleXErrors(Display *d, XErrorEvent *e) {
 //static singleton var
 Fluxbox *Fluxbox::s_singleton=0;
 
-//default values for titlebar left and right
-//don't forget to change last value in m_rc_titlebar_* if you add more to these
-Fluxbox::Titlebar Fluxbox::s_titlebar_left[] = {STICK};
-Fluxbox::Titlebar Fluxbox::s_titlebar_right[] = {MINIMIZE, MAXIMIZE, CLOSE};
-
 Fluxbox::Fluxbox(int argc, char **argv, const char *dpy_name, const char *rcfilename)
     : FbTk::App(dpy_name),
       m_fbatoms(new FbAtoms()),
@@ -205,23 +203,18 @@ Fluxbox::Fluxbox(int argc, char **argv, const char *dpy_name, const char *rcfile
       m_rc_numlayers(m_resourcemanager, 13, "session.numLayers", "Session.NumLayers"),
       m_rc_double_click_interval(m_resourcemanager, 250, "session.doubleClickInterval", "Session.DoubleClickInterval"),
       m_rc_stylefile(m_resourcemanager, DEFAULTSTYLE, "session.styleFile", "Session.StyleFile"),
+      m_rc_styleoverlayfile(m_resourcemanager, "~/.fluxbox/overlay", "session.styleOverlay", "Session.StyleOverlay"),
       m_rc_menufile(m_resourcemanager, DEFAULTMENU, "session.menuFile", "Session.MenuFile"),
       m_rc_keyfile(m_resourcemanager, DEFAULTKEYSFILE, "session.keyFile", "Session.KeyFile"),
       m_rc_slitlistfile(m_resourcemanager, "~/.fluxbox/slitlist", "session.slitlistFile", "Session.SlitlistFile"),
       m_rc_groupfile(m_resourcemanager, "~/.fluxbox/groups", "session.groupFile", "Session.GroupFile"),
       m_rc_appsfile(m_resourcemanager, "~/.fluxbox/apps", "session.appsFile", "Session.AppsFile"),
-      m_rc_titlebar_left(m_resourcemanager, 
-                         TitlebarList(&s_titlebar_left[0], &s_titlebar_left[1]), 
-                         "session.titlebar.left", "Session.Titlebar.Left"),
-      m_rc_titlebar_right(m_resourcemanager,
-                          TitlebarList(&s_titlebar_right[0], &s_titlebar_right[3]),
-                          "session.titlebar.right", "Session.Titlebar.Right"),
       m_rc_tabs_attach_area(m_resourcemanager, ATTACH_AREA_WINDOW, "session.tabsAttachArea", "Session.TabsAttachArea"),
       m_rc_cache_life(m_resourcemanager, 5, "session.cacheLife", "Session.CacheLife"),
       m_rc_cache_max(m_resourcemanager, 200, "session.cacheMax", "Session.CacheMax"),
       m_rc_auto_raise_delay(m_resourcemanager, 250, "session.autoRaiseDelay", "Session.AutoRaiseDelay"),
       m_rc_use_mod1(m_resourcemanager, true, "session.useMod1", "Session.UseMod1"),
-      m_focused_window(0), m_masked_window(0),
+      m_masked_window(0),
       m_mousescreen(0),
       m_keyscreen(0),
       m_watching_screen(0), m_watch_keyrelease(0),
@@ -299,7 +292,7 @@ Fluxbox::Fluxbox(int argc, char **argv, const char *dpy_name, const char *rcfile
 
     load_rc();
     // setup theme manager to have our style file ready to be scanned
-    FbTk::ThemeManager::instance().load(getStyleFilename());
+    FbTk::ThemeManager::instance().load(getStyleFilename(), getStyleOverlayFilename());
 
     // setup atom handlers before we create any windows
 #ifdef REMEMBER
@@ -336,10 +329,11 @@ Fluxbox::Fluxbox(int argc, char **argv, const char *dpy_name, const char *rcfile
         screens.push_back(i);
 
     // find out, on what "screens" fluxbox should run
+    // FIXME(php-coder): maybe it worths moving this code to main.cc, where command line is parsed?
     for (i = 1; i < m_argc; i++) {
         if (! strcmp(m_argv[i], "-screen")) {
             if ((++i) >= m_argc) {
-                cerr<<"error, -screen requires argument\n";
+                cerr << _FBTEXT(main, ScreenRequiresArg, "error, -screen requires argument", "the -screen option requires a file argument") << endl;
                 exit(1);
             }
 
@@ -377,9 +371,9 @@ Fluxbox::Fluxbox(int argc, char **argv, const char *dpy_name, const char *rcfile
     }
 
     m_keyscreen = m_mousescreen = m_screen_list.front();
-   
+
     // setup theme manager to have our style file ready to be scanned
-    FbTk::ThemeManager::instance().load(FbTk::StringUtil::expandFilename(getStyleFilename()));
+    FbTk::ThemeManager::instance().load(getStyleFilename(), getStyleOverlayFilename());
 
     //XSynchronize(disp, False);
     sync(false);
@@ -487,7 +481,7 @@ int Fluxbox::initScreen(int scrnr) {
 #ifdef USE_TOOLBAR
     m_toolbars.push_back(new Toolbar(*screen,
                                      *screen->layerManager().
-                                     getLayer(Fluxbox::instance()->getNormalLayer())));
+                                     getLayer(::Layer::NORMAL)));
 #endif // USE_TOOLBAR
 
     // must do this after toolbar is created
@@ -507,7 +501,7 @@ int Fluxbox::initScreen(int scrnr) {
         (*it).first->initForScreen(*screen);
     }
 
-    revertFocus(*screen); // make sure focus style is correct
+    FocusControl::revertFocus(*screen); // make sure focus style is correct
 #ifdef SLIT
     if (screen->slit())
         screen->slit()->show();
@@ -690,7 +684,7 @@ void Fluxbox::handleEvent(XEvent * const e) {
         }
 
         if (screen != 0)
-            revertFocus(*screen);
+            FocusControl::revertFocus(*screen);
     }
 
     // try FbTk::EventHandler first
@@ -866,8 +860,8 @@ void Fluxbox::handleEvent(XEvent * const e) {
             e->xfocus.detail == NotifyInferior)
             break;
         WinClient *winclient = searchWindow(e->xfocus.window);
-        if (winclient && m_focused_window != winclient)
-            setFocusedWindow(winclient);
+        if (winclient && FocusControl::focusedWindow() != winclient)
+            FocusControl::setFocusedWindow(winclient);
 
     } break;
     case FocusOut:{
@@ -882,11 +876,11 @@ void Fluxbox::handleEvent(XEvent * const e) {
 #ifdef DEBUG
             cerr<<__FILE__<<"("<<__FUNCTION__<<") Focus out is not a FluxboxWindow !!"<<endl;
 #endif // DEBUG
-        } else if (winclient && winclient == m_focused_window &&
+        } else if (winclient && winclient == FocusControl::focusedWindow() &&
                    (winclient->fbwindow() == 0
                     || !winclient->fbwindow()->isMoving()))
             // we don't unfocus a moving window
-            setFocusedWindow(0);
+            FocusControl::setFocusedWindow(0);
     }
 	break;
     case ClientMessage:
@@ -1048,9 +1042,9 @@ void Fluxbox::handleClientMessage(XClientMessageEvent &ce) {
 
         if (screen) {
             if (! ce.data.l[0])
-                screen->prevFocus();
+                screen->focusControl().prevFocus();
             else
-                screen->nextFocus();
+                screen->focusControl().nextFocus();
         }
     } else if (ce.message_type == m_fbatoms->getFluxboxChangeAttributesAtom()) {
         WinClient *winclient = searchWindow(ce.window);
@@ -1220,8 +1214,8 @@ void Fluxbox::update(FbTk::Subject *changedsub) {
             // make sure each workspace get this
             BScreen &scr = win.screen();
             scr.removeWindow(&win);
-            if (m_focused_window == &win.winClient())
-                m_focused_window = 0;
+            if (FocusControl::focusedWindow() == &win.winClient())
+                FocusControl::setFocusedWindow(0);
 
         } else if ((&(win.workspaceSig())) == changedsub) {  // workspace signal
             for (AtomHandlerContainerIt it= m_atomhandler.begin();
@@ -1293,12 +1287,12 @@ void Fluxbox::update(FbTk::Subject *changedsub) {
 
         // This is where we revert focus on window close
         // NOWHERE ELSE!!!
-        if (m_focused_window == &client)
-            unfocusWindow(client);
+        if (FocusControl::focusedWindow() == &client)
+            FocusControl::unfocusWindow(client);
 
         // failed to revert focus?
-        if (m_focused_window == &client)
-            m_focused_window = 0;
+        if (FocusControl::focusedWindow() == &client)
+            FocusControl::setFocusedWindow(0);
     }
 }
 
@@ -1587,7 +1581,7 @@ void Fluxbox::load_rc(BScreen &screen) {
             if (!(*it).empty() && (*it) != "")
             screen.addWorkspaceName((*it).c_str());
         }
-        
+
     }
 
     FbTk::Image::removeAllSearchPaths();
@@ -1792,73 +1786,22 @@ void Fluxbox::timed_reconfigure() {
     m_reconfigure_wait = m_reread_menu_wait = false;
 }
 
-// set focused window
-void Fluxbox::setFocusedWindow(WinClient *client) {
-    // already focused
-    if (m_focused_window == client) {
-#ifdef DEBUG
-        cerr<<"Focused window already win"<<endl;
-#endif // DEBUG
-        return;
-    }
-#ifdef DEBUG
-    cerr<<"Setting Focused window = "<<client<<endl;
-    if (client != 0 && client->fbwindow() != 0)
-        cerr<<"title: "<<client->fbwindow()->title()<<endl;
-    cerr<<"Current Focused window = "<<m_focused_window<<endl;
-    cerr<<"------------------"<<endl;
-#endif // DEBUG
-    BScreen *old_screen = 0, *screen = 0;
-    WinClient *old_client = 0;
-
-    if (m_focused_window != 0) {
-        // check if m_focused_window is valid
-        WinClientMap::iterator it = find_if(m_window_search.begin(),
-                                            m_window_search.end(),
-                                            Compose(bind2nd(equal_to<WinClient *>(), m_focused_window),
-                                                    Select2nd<WinClientMap::value_type>()));
-                
-        // if not found...
-        if (it == m_window_search.end()) {
-            m_focused_window = 0;
-        } else {
-            old_client = m_focused_window;
-            old_screen = &old_client->screen();
-
-            if (old_client->fbwindow()) {
-                FluxboxWindow *old_win = old_client->fbwindow();
-
-                if (!client || client->fbwindow() != old_win)
-                    old_win->setFocusFlag(false);
-            }
-        }
-    }
-
-    if (client && client->fbwindow() && !client->fbwindow()->isIconic()) {
-        FluxboxWindow *win = client->fbwindow();
-        // make sure we have a valid win pointer with a valid screen
-        ScreenList::iterator winscreen =
-            std::find(m_screen_list.begin(), m_screen_list.end(),
-                      &client->screen());
-        if (winscreen == m_screen_list.end()) {
-            m_focused_window = 0; // the window pointer wasn't valid, mark no window focused
-        } else {
-            screen = *winscreen;
-            m_focused_window = client;     // update focused window
-            win->setCurrentClient(*client, false); // don't setinputfocus
-            win->setFocusFlag(true); // set focus flag
-        }
-
-    } else
-        m_focused_window = 0;
-
+bool Fluxbox::validateClient(const WinClient *client) const {
+    WinClientMap::const_iterator it = 
+        find_if(m_window_search.begin(),
+                m_window_search.end(),
+                Compose(bind2nd(equal_to<WinClient *>(), client),
+                        Select2nd<WinClientMap::value_type>()));
+    return it != m_window_search.end();
+}
 
+void Fluxbox::updateFocusedWindow(BScreen *screen, BScreen *old_screen) {
     if (screen != 0) {
         screen->updateNetizenWindowFocus();
         for (AtomHandlerContainerIt it= m_atomhandler.begin();
              it != m_atomhandler.end(); it++) {
-            (*it).first->updateFocusedWindow(*screen, (m_focused_window ?
-                                                       m_focused_window->window() :
+            (*it).first->updateFocusedWindow(*screen, (FocusControl::focusedWindow() ?
+                                                       FocusControl::focusedWindow()->window() :
                                                        0));
         }
     }
@@ -1871,88 +1814,6 @@ void Fluxbox::setFocusedWindow(WinClient *client) {
     }
 }
 
-/**
- * This function is called whenever we aren't quite sure what
- * focus is meant to be, it'll make things right ;-)
- * last_focused is set to something if we want to make use of the
- * previously focused window (it must NOT be set focused now, it
- *   is probably dying).
- *
- * ignore_event means that it ignores the given event until
- * it gets a focusIn
- */
-void Fluxbox::revertFocus(BScreen &screen) {
-    // Relevant resources:
-    // resource.focus_last = whether we focus last focused when changing workspace
-    // BScreen::FocusModel = sloppy, click, whatever
-    WinClient *next_focus = screen.getLastFocusedWindow(screen.currentWorkspaceID());
-
-    // if setting focus fails, or isn't possible, fallback correctly
-    if (!(next_focus && next_focus->fbwindow() &&
-          next_focus->fbwindow()->setCurrentClient(*next_focus, true))) {
-        setFocusedWindow(0); // so we don't get dangling m_focused_window pointer
-        switch (screen.getFocusModel()) {
-        case BScreen::MOUSEFOCUS:
-            XSetInputFocus(FbTk::App::instance()->display(),
-                           PointerRoot, None, CurrentTime);
-            break;
-        case BScreen::CLICKFOCUS:
-            screen.rootWindow().setInputFocus(RevertToPointerRoot, CurrentTime);
-            break;
-        }
-    }
-}
-
-/*
- * Like revertFocus, but specifically related to this window (transients etc)
- * if full_revert, we fallback to a full revertFocus if we can't find anything
- * local to the client.
- * If unfocus_frame is true, we won't focus anything in the same frame
- * as the client.
- *
- * So, we first prefer to choose a transient parent, then the last
- * client in this window, and if no luck (or unfocus_frame), then
- * we just use the normal revertFocus on the screen.
- *
- * assumption: client has focus
- */
-void Fluxbox::unfocusWindow(WinClient &client, bool full_revert, bool unfocus_frame) {
-    // go up the transient tree looking for a focusable window
-
-    FluxboxWindow *fbwin = client.fbwindow();
-    if (fbwin == 0)
-        unfocus_frame = false;
-
-    WinClient *trans_parent = client.transientFor();
-    while (trans_parent) {
-        if (trans_parent->fbwindow() && // can't focus if no fbwin
-            (!unfocus_frame || trans_parent->fbwindow() != fbwin) && // can't be this window
-            trans_parent->fbwindow()->isVisible() &&
-            trans_parent->fbwindow()->setCurrentClient(*trans_parent, m_focused_window == &client)) {
-            return;
-        }
-        trans_parent = trans_parent->transientFor();
-    }
-
-    if (fbwin == 0)
-        return; // nothing more we can do
-
-    BScreen &screen = fbwin->screen();
-
-    if (!unfocus_frame) {
-        WinClient *last_focus = screen.getLastFocusedWindow(*fbwin, &client);
-        if (last_focus != 0 &&
-            fbwin->setCurrentClient(*last_focus, m_focused_window == &client)) {
-            return;
-        }
-    }
-
-    if (full_revert && m_focused_window == &client)
-        revertFocus(screen);
-
-}
-
-
 void Fluxbox::watchKeyRelease(BScreen &screen, unsigned int mods) {
     
     if (mods == 0) {
