@@ -1,5 +1,5 @@
 // main.cc for Fluxbox Window manager
-// Copyright (c) 2001 - 2005 Henrik Kinnunen (fluxgen at fluxbox dot org)
+// Copyright (c) 2001 - 2006 Henrik Kinnunen (fluxgen at fluxbox dot org)
 //               and 2003-2005 Simon Bowden (rathnor at users.sourceforge.net)
 //
 // Permission is hereby granted, free of charge, to any person obtaining a
@@ -20,7 +20,7 @@
 // FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 // DEALINGS IN THE SOFTWARE.
 
-// $Id: main.cc 4095 2005-08-31 20:15:01Z fluxgen $
+// $Id: main.cc 4251 2006-03-18 22:21:49Z fluxgen $
 
 #include "fluxbox.hh"
 #include "version.h"
@@ -207,7 +207,7 @@ int main(int argc, char **argv) {
             }
         } else if (strcmp(argv[i], "-version") == 0 || strcmp(argv[i], "-v") == 0) {
             // print current version string
-            cout<<"Fluxbox "<<__fluxbox_version<<" : (c) 2001-2005 Henrik Kinnunen "<<endl<<endl;
+            cout << "Fluxbox " << __fluxbox_version << " : (c) 2001-2006 Henrik Kinnunen " << endl << endl;
             exit(0);
         } else if (strcmp(argv[i], "-log") == 0 ) {
             if (i + 1 >= argc) {
@@ -220,16 +220,16 @@ int main(int argc, char **argv) {
             printf(_FBTEXT(main, Usage,
                            "Fluxbox %s : (c) %s Henrik Kinnunen\n"
                            "Website: http://www.fluxbox.org/ \n\n"
-                           "\t-display <string>\t\tuse display connection.\n"
-                           "\t-screen <all|int,int,int>\trun on specified screens only.\n"
-                           "\t-rc <string>\t\t\tuse alternate resource file.\n"
-                           "\t-version\t\t\tdisplay version and exit.\n"
-                           "\t-info\t\t\t\tdisplay some useful information.\n"
-                           "\t-log <filename>\t\t\tlog output to file.\n"
-                           "\t-help\t\t\t\tdisplay this help text and exit.\n\n",
+                           "-display <string>\t\tuse display connection.\n"
+                           "-screen <all|int,int,int>\trun on specified screens only.\n"
+                           "-rc <string>\t\t\tuse alternate resource file.\n"
+                           "-version\t\t\tdisplay version and exit.\n"
+                           "-info\t\t\t\tdisplay some useful information.\n"
+                           "-log <filename>\t\t\tlog output to file.\n"
+                           "-help\t\t\t\tdisplay this help text and exit.\n\n",
 
                            "Main usage string. Please lay it out nicely. There is one %s that is given the version"),
-                   __fluxbox_version, "2001-2005");
+                   __fluxbox_version, "2001-2006");
             exit(0);
         } else if (strcmp(argv[i], "-info") == 0 || strcmp(argv[i], "-i") == 0) {
             showInfo(cout);
